'''
 Web的MVC三层结构是互联网最火的应用框架。
 系统需要切分为模型、视图、控制三层。
 Python 中最简单的 Web服务器是 flask 
    app.py - Flask应用的主文件，控制器（Controller）。
    models.py - 模型（Model）文件，包含词频统计的逻辑。
    templates/index.html - 视图（View）文件，用于展示结果。
 '''


from flask import Flask, render_template, request
from models import WordFrequencyModel

app = Flask(__name__)
app.config['SECRET_KEY'] = 'your-secret-key'

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/count', methods=['POST'])
def count_words():
    text = request.form.get('text', '').lower()
    model = WordFrequencyModel()
    top_words = model.get_top_n_words(text, 10)
    return render_template('index.html', top_words=top_words)

if __name__ == '__main__':
    app.run(debug=True)